pub fn wasm_execute() -> TransformDefExpand description
Create a WASM-execute transform definition
Use this when the transform requires complex logic that can’t be expressed as a simple template.
pub fn wasm_execute() -> TransformDefCreate a WASM-execute transform definition
Use this when the transform requires complex logic that can’t be expressed as a simple template.